Downloads a standardized gene annotation table for human or mouse using
biomaRt. Includes Ensembl ID, gene symbol, Entrez ID, gene type,
chromosome location, and other metadata.
Usage
download_gene_ref(species = c("human", "mouse"), dest = NULL)Downloads a standardized gene annotation table for human or mouse using
biomaRt. Includes Ensembl ID, gene symbol, Entrez ID, gene type,
chromosome location, and other metadata.
download_gene_ref(species = c("human", "mouse"), dest = NULL)