| gmt2list | R Documentation |
Reads a .gmt gene set file and returns a named list, where each list element is a gene set.
gmt2list(file, verbose = TRUE)
file |
Character. Path to a .gmt file. |
verbose |
Logical. Whether to print message. Default is TRUE. |
A named list where each element is a character vector of gene symbols.
## Not run:
# Requires a GMT file to run:
gmt_file <- "path/to/geneset.gmt"
gene_sets <- gmt2list(gmt_file)
length(gene_sets)
names(gene_sets)[1:3]
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.