| %p% | R Documentation |
%p%: paste two strings with a single spaceAn infix operator for string concatenation with one space between lhs and rhs.
Inspired by the readability of %>%, intended for expressive text building.
lhs %p% rhs
lhs |
A character vector on the left-hand side. |
rhs |
A character vector on the right-hand side. |
A character vector, concatenating lhs and rhs with a single space.
"Hello" %p% "world"
"Good" %p% "job"
c("hello", "good") %p% c("world", "morning") # vectorized
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.