palette_cache_info: Get Palette Cache Information

View source: R/zzz.R

palette_cache_infoR Documentation

Get Palette Cache Information

Description

Display information about the current palette cache status, including whether it's initialized, when it was loaded, and how many palettes are cached.

Usage

palette_cache_info()

Value

List with cache information (invisible)

Examples

## Not run: 
# Check cache status
palette_cache_info()

## End(Not run)


evanverse documentation built on March 10, 2026, 5:07 p.m.