Configure CRAN and/or Bioconductor mirrors for faster package installation. R's native installation functions, BiocManager, and pak can respect these settings once set.
Usage
set_mirror(repo = c("all", "cran", "bioc"), mirror = "tuna")Configure CRAN and/or Bioconductor mirrors for faster package installation. R's native installation functions, BiocManager, and pak can respect these settings once set.
set_mirror(repo = c("all", "cran", "bioc"), mirror = "tuna")