Like %match%, but returns a named character vector instead of indices.
Names are canonical entries from table; values are the original elements from x.
Unmatched values are dropped.
Like %match%, but returns a named character vector instead of indices.
Names are canonical entries from table; values are the original elements from x.
Unmatched values are dropped.