| palette_cache_info | R Documentation |
Display information about the current palette cache status, including whether it's initialized, when it was loaded, and how many palettes are cached.
palette_cache_info()
List with cache information (invisible)
## Not run:
# Check cache status
palette_cache_info()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.